UninstallCommand class

Mixed-in types

Constructors

UninstallCommand()
const

Properties

gitDir String?
no setterinherited
gitHooksDir String?
Alias for managedHooksDir (kept for existing call sites / tests).
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
managedHooksDir String?
Managed shim directory Git runs via core.hooksPath (hooks/_).
no setterinherited
root String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dartToolGitHooksDir(String root) → Directory
inherited
executablesDir(String root) → Directory
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run() Future<int>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited