AnyHook class
Properties
-
backup
→ bool
-
Whether to snapshot the index and working tree before the tasks run and
roll back to it when the hook fails.
finalinherited
-
diffArgs
→ List<String>
-
Defaults to
'--staged'
finalinherited
-
diffFilters
→ String
-
Defaults to 'ACMR'
finalinherited
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
props
→ List<Object?>
-
The list of properties that will be used to determine whether
two instances are equal.
no setterinherited
-
runInParallel
→ bool
-
Whether to run the top level tasks in parallel
finalinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
shouldRunOnEmpty
→ bool
-
no setterinherited
-
stringify
→ bool?
-
If set to
true, the toString method will be overridden to output
this instance's props.
no setterinherited
-
tasks
→ List<HookTask>
-
finalinherited
-
verbose
→ bool
-
finalinherited