Compiler class
Constructors
- Compiler()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
compile(
{required String file, required String outFile}) → Future< ProcessResult> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
prepareShellExecutable(
{required String file, required String outFile}) → Future< ProcessResult> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
ctor
↔ Future<
ProcessResult> Function(String executable, List<String> arguments, {Map<String, String> ? environment, bool includeParentEnvironment, bool runInShell, Encoding? stderrEncoding, Encoding? stdoutEncoding, String? workingDirectory}) -
getter/setter pair
- isWindows ↔ bool Function()
-
Overridable for tests (
Platform.isWindowsis not mockable).getter/setter pair