ResolvedHookTask class

Constructors

ResolvedHookTask({required List<String> files, required String? workingDirectory, required HookTask original, required int index, required TaskLabel label, required List<ResolvedHookTask> subTasks, required bool always})
const

Properties

always → bool
final
fileCount → int
no setter
files → List<String>
final
hasChildren → bool
no setter
hasFiles → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
index → int
final
label → TaskLabel
final
name → String
no setter
original → HookTask
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subTasks → List<ResolvedHookTask>
final
workingDirectory → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited