TaskLabel class

Constructors

TaskLabel(String name, {required String taskId, required int fileCount, List<TaskLabel> children = const []})
const

Properties

children → List<TaskLabel>
final
depth → int
no setter
fileCount → int
final
hasChildren → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
length → int
no setter
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
taskId → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited