HooksmanApp class
Constructors
- HooksmanApp({required PendingHook pendingHook, required String nameOfHook, required bool debug, required Steps steps, Key? key})
-
const
Properties
- debug → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
finalinherited
- nameOfHook → String
-
final
- pendingHook → PendingHook
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- steps → Steps
-
final
Methods
-
createElement(
) → StatefulElement -
inherited
-
createState(
) → State< HooksmanApp> - Creates the mutable state for this component.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited