HookContext class
Runtime context for a Git hook invocation (args + stdin).
Constructors
-
HookContext({required List<
String> args, String stdin = '', String? messageFile}) -
const
Properties
-
args
→ List<
String> -
Positional arguments Git passed to the hook (
$1,$2, …).final - hashCode → int
-
The hash code for this object.
no setterinherited
- messageFile → String?
-
Convenience for
commit-msg/prepare-commit-msg: path from$1.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stdin → String
-
Stdin contents Git piped to the hook (e.g. refs for
pre-push).final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- empty → const HookContext