tasks/re_register_hooks library

Classes

ReRegisterHooks
The ReRegisterHooks task automates the process of re-registering Git hooks whenever any hook files are created, modified, or deleted. This ensures that changes to your hooks are applied: Dart sources are compiled into executables under .dart_tool/hooksman/, and thin shims are written to hooks/_ (Git's core.hooksPath).